@@ -29,7 +29,7 @@ class Composition : public Segmentation {
   string GetPrompt() const;
   string GetCommitText() const;
   string GetScriptText(bool keep_selection = true) const;
-  RIME_API string GetDebugText() const;
+  RIME_DLL string GetDebugText() const;
   // Returns text of the last segment before the given position.
   string GetTextBefore(size_t pos) const;
 };
