@@ -4,6 +4,7 @@
 //
 // 2011-05-08 GONG Chen <chen.sst@gmail.com>
 //
+#include <algorithm>
 #include <utility>
 #include <rime/candidate.h>
 #include <rime/context.h>
@@ -127,12 +128,9 @@ bool Context::Highlight(size_t index) {
   if (composition_.empty() || !composition_.back().menu)
     return false;
   Segment& seg(composition_.back());
-  size_t new_index = index;
   size_t candidate_count = seg.menu->Prepare(index + 1);
-  if (index >= candidate_count) {
-    DLOG(INFO) << "selection index exceeds candidate pool, fallback to last";
-    new_index = candidate_count - 1;
-  }
+  size_t new_index =
+      candidate_count > 0 ? (std::min)(candidate_count - 1, index) : 0;
   size_t previous_index = seg.selected_index;
   if (previous_index == new_index) {
     DLOG(INFO) << "selection has not changed, currently at " << new_index;
@@ -145,27 +143,21 @@ bool Context::Highlight(size_t index) {
   return true;
 }
 
-bool Context::DeleteCandidate(
-    function<an<Candidate>(Segment& seg)> get_candidate) {
+bool Context::DeleteCandidate(size_t index) {
   if (composition_.empty())
     return false;
   Segment& seg(composition_.back());
-  if (auto cand = get_candidate(seg)) {
-    DLOG(INFO) << "Deleting candidate: '" << cand->text();
-    delete_notifier_(this);
-    return true;  // CAVEAT: this doesn't mean anything is deleted for sure
-  }
-  return false;
-}
-
-bool Context::DeleteCandidate(size_t index) {
-  return DeleteCandidate(
-      [index](Segment& seg) { return seg.GetCandidateAt(index); });
+  seg.selected_index = index;
+  DLOG(INFO) << "Deleting candidate: " << seg.GetSelectedCandidate()->text();
+  delete_notifier_(this);
+  return true;  // CAVEAT: this doesn't mean anything is deleted for sure
 }
 
 bool Context::DeleteCurrentSelection() {
-  return DeleteCandidate(
-      [](Segment& seg) { return seg.GetSelectedCandidate(); });
+  if (composition_.empty())
+    return false;
+  Segment& seg(composition_.back());
+  return DeleteCandidate(seg.selected_index);
 }
 
 bool Context::ConfirmCurrentSelection() {
