@@ -18,10 +18,9 @@
 #include <rime/gear/translator_commons.h>
 #include <rime/gear/table_translator.h>
 
-
-//static const char* quote_left = "\xef\xbc\x88";
-//static const char* quote_right = "\xef\xbc\x89";
-//static const char* separator = "\xef\xbc\x8c";
+// static const char* quote_left = "\xef\xbc\x88";
+// static const char* quote_right = "\xef\xbc\x89";
+// static const char* separator = "\xef\xbc\x8c";
 
 namespace rime {
 
@@ -30,17 +29,24 @@ class ReverseLookupTranslation : public TableTranslation {
   ReverseLookupTranslation(ReverseLookupDictionary* dict,
                            TranslatorOptions* options,
                            const string& input,
-                           size_t start, size_t end,
+                           size_t start,
+                           size_t end,
                            const string& preedit,
                            DictEntryIterator&& iter,
                            bool quality)
-      : TableTranslation(
-            options, NULL, input, start, end, preedit, std::move(iter)),
-        dict_(dict), options_(options), quality_(quality) {
-  }
+      : TableTranslation(options,
+                         NULL,
+                         input,
+                         start,
+                         end,
+                         preedit,
+                         std::move(iter)),
+        dict_(dict),
+        options_(options),
+        quality_(quality) {}
   virtual an<Candidate> Peek();
-  virtual int Compare(an<Translation> other,
-                      const CandidateList& candidates);
+  virtual int Compare(an<Translation> other, const CandidateList& candidates);
+
  protected:
   ReverseLookupDictionary* dict_;
   TranslatorOptions* options_;
@@ -57,17 +63,13 @@ an<Candidate> ReverseLookupTranslation::Peek() {
     if (options_) {
       options_->comment_formatter().Apply(&tips);
     }
-    //if (!tips.empty()) {
-    //  boost::algorithm::replace_all(tips, " ", separator);
-    //}
+    // if (!tips.empty()) {
+    //   boost::algorithm::replace_all(tips, " ", separator);
+    // }
   }
-  an<Candidate> cand = New<SimpleCandidate>(
-      "reverse_lookup",
-      start_,
-      end_,
-      entry->text,
-      !tips.empty() ? tips : entry->comment,
-      preedit_);
+  an<Candidate> cand =
+      New<SimpleCandidate>("reverse_lookup", start_, end_, entry->text,
+                           !tips.empty() ? tips : entry->comment, preedit_);
   return cand;
 }
 
@@ -121,8 +123,7 @@ void ReverseLookupTranslator::Initialize() {
   }
   if (dict_) {
     dict_->Load();
-  }
-  else {
+  } else {
     return;
   }
   auto rev_component =
@@ -140,15 +141,15 @@ void ReverseLookupTranslator::Initialize() {
 }
 
 an<Translation> ReverseLookupTranslator::Query(const string& input,
-                                                       const Segment& segment) {
+                                               const Segment& segment) {
   if (!segment.HasTag(tag_))
     return nullptr;
   if (!initialized_)
     Initialize();  // load reverse dict at first use
   if (!dict_ || !dict_->loaded())
     return nullptr;
-  DLOG(INFO) << "input = '" << input
-             << "', [" << segment.start << ", " << segment.end << ")";
+  DLOG(INFO) << "input = '" << input << "', [" << segment.start << ", "
+             << segment.end << ")";
 
   const string& preedit(input);
 
@@ -172,36 +173,28 @@ an<Translation> ReverseLookupTranslator::Query(const string& input,
   if (start < input.length()) {
     if (options_ && options_->enable_completion()) {
       dict_->LookupWords(&iter, code, true, 100);
-      quality = !iter.exhausted() &&
-                (iter.Peek()->remaining_code_length == 0);
-    }
-    else {
+      quality = !iter.exhausted() && (iter.Peek()->remaining_code_length == 0);
+    } else {
       // 2012-04-08 gongchen: fetch multi-syllable words from rev-lookup table
       SyllableGraph graph;
       Syllabifier syllabifier("", true, options_->strict_spelling());
-      size_t consumed = syllabifier.BuildSyllableGraph(code,
-                                                       *dict_->prism(),
-                                                       &graph);
+      size_t consumed =
+          syllabifier.BuildSyllableGraph(code, *dict_->prism(), &graph);
       if (consumed == code.length()) {
         auto collector = dict_->Lookup(graph, 0);
         if (collector && !collector->empty() &&
             collector->rbegin()->first == consumed) {
           iter = std::move(collector->rbegin()->second);
           quality = !graph.vertices.empty() &&
-              (graph.vertices.rbegin()->second == kNormalSpelling);
+                    (graph.vertices.rbegin()->second == kNormalSpelling);
         }
       }
     }
   }
   if (!iter.exhausted()) {
-    return Cached<ReverseLookupTranslation>(rev_dict_.get(),
-                                            options_.get(),
-                                            code,
-                                            segment.start,
-                                            segment.end,
-                                            preedit,
-                                            std::move(iter),
-                                            quality);
+    return Cached<ReverseLookupTranslation>(rev_dict_.get(), options_.get(),
+                                            code, segment.start, segment.end,
+                                            preedit, std::move(iter), quality);
   }
   return nullptr;
 }
