@@ -15,8 +15,7 @@ class SwitchTranslator : public Translator {
  public:
   SwitchTranslator(const Ticket& ticket);
 
-  virtual an<Translation> Query(const string& input,
-                                        const Segment& segment);
+  an<Translation> Query(const string& input, const Segment& segment) override;
 };
 
 }  // namespace rime
